@@ -1,11 +1,12 @@
-from lazyTest.file import IniFileOperation
+from lazyTest.file import IniFileOperation,Csv_File_Operation
 from lazyTest.log import GetLogger
 from lazyTest.utils import Sleep, readElementSource,writeElementKey, ClearTestResult, createData,cls_Sleep
 from lazyTest.case import TestCase
 from lazyTest.base import  browser_Config
 from lazyTest.page import Page
 
-__version__ = '1.0.7'
+__version__ = '1.0.9'
+
 
 __description__ = ""
 
@@ -21,4 +22,5 @@ __all__ = [
     "IniFileOperation",
     "TestCase",
     "cls_Sleep",
+    "Csv_File_Operation"
 ]
