@@ -5,24 +5,13 @@
 # time     : 2020/12/14 16:39
 # Describe : 
 # ---------------------------------------
+
 import argparse
-import os, ssl, sys, platform
+import os, sys
 from lazyTest import __version__, __description__
 
 PY3 = sys.version_info[0] == 3
 
-versions = sorted(['32', '64'], key=lambda v: not platform.machine().endswith(v))
-os_opts = [('win', 'win', '.exe'), ('darwin', 'mac', ''), ('linux', 'linux', '')]
-
-current_os = None
-ext = ''
-for o in os_opts:
-    if o[0] in platform.system().lower():
-        current_os = o[1]
-        ext = o[2]
-
-ssl._create_default_https_context = ssl._create_unverified_context
-
 
 def main():
     """
@@ -145,13 +134,22 @@ def flush_browser(getdriver):
 # 用例出现异常或失败时截图
 @pytest.hookimpl(hookwrapper=True)
 def pytest_runtest_makereport():
+<<<<<<< HEAD
+=======
     picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
     filename = getPorjectPath() + globals()["filepath"] + picture_time + ".png"
+>>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
     outcome = yield
     report = outcome.get_result()
     if report.when == 'call':
         xfail = hasattr(report, 'wasxfail')
+<<<<<<< HEAD
+        if report.failed and not xfail:
+            picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
+            filename = getPorjectPath() + globals()["filepath"] + picture_time + ".png"
+=======
         if (report.skipped and xfail) or (report.failed and not xfail):
+>>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
             globals()["driver"].save_screenshot(filename)
             with open(filename, "rb") as f:
                 file = f.read()
@@ -172,7 +170,11 @@ import sys
 import time
 
 sys.path.append(os.path.dirname(os.path.dirname(__file__)))
+<<<<<<< HEAD
+from lazyTest import ClearTestResult
+=======
 from lazy import ClearTestResult
+>>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
 
 
 def getPorjectPath():
@@ -244,3 +246,4 @@ run()
 
 if __name__ == '__main__':
     main()
+
