@@ -5,16 +5,13 @@
 # time     : 2020/12/3 11:56
 # Describe :
 # ---------------------------------------
-import sys
-import inspect
+
 
 from lazyTest import *
 
 
 class Page(object):
-    module = sys._getframe().f_code.co_name
-
-    filePath = r"/resources/elementSource/"
+    filePath = r"/resources/element/"
 
     suffix = ".yaml"
 
@@ -22,32 +19,33 @@ class Page(object):
 
     logName = "log.log"
 
-    def getPorjectPath(self):
-        ...
+    def getPorjectPath(self) -> str: ...
+
+    @classmethod
+    def getClassName(cls):
+        return cls.__name__
 
     def __init__(self, base_driver: browser_Config) -> None:
         self.base_driver = base_driver
         self.log = GetLogger(self.getPorjectPath() + self.logPath + self.logName).logger
+        self.log.info("元素文件: -> %s" % self.getPorjectPath() + self.filePath + self.getClassName() + self.suffix)
         self.selector = readElementSource(
-            self.getPorjectPath() + self.filePath + self.module + self.suffix).readFileToDict()
+            self.getPorjectPath() + self.filePath + self.getClassName() + self.suffix).readFileToDict()
 
     @classmethod
     def writeKey(cls):
-        '''
+        """
         自动创建yaml资源文件
-        :param filepath: 从项目路径下开始指定目录
-        :param fileType: 默认yaml文件格式
         :return:
-        '''
+        """
         key = {}
         methods = list(
             filter(lambda m: not m.startswith("__") and not m.endswith("__") and callable(getattr(cls, m)), dir(cls)))
         methods.pop(methods.index("writeKey"))
         methods.pop(methods.index("getPorjectPath"))
+        methods.pop(methods.index("getClassName"))
         for i in methods:
             func = getattr(cls, i)
-            params = list(inspect.getfullargspec(func))[0]
-            if params.count('self') > 0:
-                params.remove("self")
-            key[i] = params
-        writeElementKey(cls.getPorjectPath(cls) + cls.filePath, cls.module, cls.suffix, key)
+            doc = func.__doc__
+            key[i] = doc
+        writeElementKey(cls.getPorjectPath(cls) + cls.filePath, cls.getClassName(), cls.suffix, key)
