@@ -36,15 +36,18 @@ def Sleep(s: int = 1):
     return Sleep
 
 
-def cls_Sleep(s : int = 0.2):
+
+def cls_Sleep(s: int = 0.2):
     def decorator(cls):
-        origin_getattribute=cls.__getattribute__
+        origin_getattribute = cls.__getattribute__
+
         @functools.wraps(cls)
-        def new_getattribute(*args,**kwargs):
+        def new_getattribute(*args, **kwargs):
             time.sleep(s)
-            inner = origin_getattribute(*args,**kwargs)
+            inner = origin_getattribute(*args, **kwargs)
             return inner
-        cls.__getattribute__=new_getattribute
+
+        cls.__getattribute__ = new_getattribute
         return cls
     return decorator
 
@@ -91,17 +94,20 @@ def readElementSource(fileName: str) -> FileOperation:
         else:
             raise Exception("文件类型错误")
 
-def writeElementKey(filepath,fileName,fileType,data : dict):
+
+def writeElementKey(filepath, fileName, fileType, data: dict):
     # 得到完整文件路径
-    realFile =  filepath + fileName + fileType
+    realFile = filepath + fileName + fileType
     if os.path.exists(realFile):
         print("文件已存在不进行写入")
     else:
         newdata = {}
+        file = None
         for i in data:
-            newdata[i.upper()] = None
-            for j in data[i]:
-                newdata[j.upper()] = None
-        YamlOperation.writeFileToDict(realFile,newdata)
-        print("文件写入成功！！！")
-
+            newdata[i.upper()] = data[i]
+        if fileType == '.yaml':
+            file = YamlOperation
+        elif fileType == '.json':
+            file = JsonFileOperation
+        file.writeFileToDict(realFile, newdata)
+        print("文件写入成功！！！")
\ No newline at end of file
